﻿using System;
using System.Text;
using System.Globalization;
namespace Persistence {

  public interface IPrimitiveSerializer {
    Type Type { get; }
    object Serialize(object o);
    object DeSerialize(object o);
  }

  public class String2XMLSerializer : IPrimitiveSerializer {
    public Type Type { get { return typeof(string); } }
    public object Serialize(object o) {
      return "<![CDATA[" +
        ((string)o).Replace("]]>", "]]]]><![CDATA[>") +
        "]]>";
    }
    public object DeSerialize(object o) {
      StringBuilder sb = new StringBuilder();
      foreach (string s in ((string)o).Split(
        new string[] { "<![CDATA[", "]]>" },
        StringSplitOptions.RemoveEmptyEntries)) {
        sb.Append(s);
      }
      return sb.ToString();
    }
  }
  public class Int2XMLSerializer : IPrimitiveSerializer {
    public Type Type { get { return typeof(int); } }
    public object Serialize(object o) {
      return ((int)o).ToString();
    }
    public object DeSerialize(object o) {
      return int.Parse((string)o);
    }
  }
  public class Double2XmlSerializer : IPrimitiveSerializer {    
    public Type Type { get { return typeof(double); } }        
    public object Serialize(object o) {
      return ((double)o).ToString("r", CultureInfo.InvariantCulture);      
    }
    public object DeSerialize(object o) {
      return double.Parse((string)o, CultureInfo.InvariantCulture);
    }
  }
}